@@ -1,6 +1,6 @@
 __all__ = ('RequestPhotoVerificationPoint', 'RequestVideoVerificationPoint',
-           'AutoVerificationTaskPoint', 'VideoVerificationProcessPoint', 'PhotoVerificationProcessPoint',
-           )
+           'AutoVerificationTaskPoint', 'VideoVerificationProcessPoint',
+           'PhotoVerificationProcessPoint', 'RuVerificatorResultReceiverPoint',)
 
 from expressmoney.api import *
 
@@ -91,6 +91,20 @@ class PhotoVerificationProcessReadContract(Contract):
     message = serializers.CharField(max_length=64, allow_blank=True)
 
 
+class RuVerificatorResultReceiverCreateContract(Contract):
+    EMPTY = 'EMPTY'
+    SUCCESS = 'SCS'
+    FAILURE = 'FAIL'
+    RESULT_CHOICES = (
+        (EMPTY, EMPTY),
+        (FAILURE, FAILURE),
+        (SUCCESS, SUCCESS),
+    )
+    user_id = serializers.IntegerField(min_value=1)
+    result = serializers.ChoiceField(choices=RESULT_CHOICES)
+    comment = serializers.CharField(max_length=500, allow_blank=True)
+
+
 class RequestPhotoVerificationID(ID):
     _service = SERVICE
     _app = 'verification'
@@ -121,6 +135,12 @@ class PhotoVerificationProcessID(ID):
     _view_set = 'photo_verification_process'
 
 
+class RuVerificatorResultReceiverPointID(ID):
+    _service = SERVICE
+    _app = 'verification'
+    _view_set = 'ru_verificator_result_receiver'
+
+
 class RequestPhotoVerificationPoint(CreatePointMixin, ContractPoint):
     _point_id = RequestPhotoVerificationID()
     _create_contract = RequestPhotoVerificationCreateContract
@@ -144,3 +164,8 @@ class VideoVerificationProcessPoint(ListPointMixin, ContractPoint):
 class PhotoVerificationProcessPoint(ListPointMixin, ContractPoint):
     _point_id = PhotoVerificationProcessID()
     _read_contract = PhotoVerificationProcessReadContract
+
+
+class RuVerificatorResultReceiverPoint(CreatePointMixin, ContractPoint):
+    _point_id = RuVerificatorResultReceiverPointID()
+    _create_contract = RuVerificatorResultReceiverCreateContract
